[![Documentation Status](https://readthedocs.org/projects/pyhashlookup/badge/?version=latest)](https://pyhashlookup.readthedocs.io/en/latest/?badge=latest)

# PyHashlookup

This is the client API for [hashlookup](https://hashlookup.circl.lu/).

## Installation

```bash
pip install pyhashlookup
```

## Usage

### Command line

```bash
usage: hashlookup [-h] [--query QUERY]

Query hashlookup

optional arguments:
  -h, --help     show this help message and exit
    --query QUERY  Hash (md5 or sha1) to lookup.
```

### Library

See [API Reference](https://pyhashlookup.readthedocs.io/en/latest/api_reference.html)
